@@ -1,3 +1,4 @@
+#include "Mdefines.h"
 #include "sparseVector.h"
 
 SEXP v2spV(SEXP from)
@@ -9,7 +10,7 @@ SEXP v2spV(SEXP from)
 	          _CTYPE1_, _SEXPTYPE1_, _PTR1_, \
 	          _CTYPE2_, _SEXPTYPE2_, _PTR2_) \
 	do { \
-		PROTECT(to = NEW_OBJECT_OF_CLASS(#_KIND_ "sparseVector")); \
+		PROTECT(to = newObject(#_KIND_ "sparseVector")); \
 		_CTYPE1_ *py = _PTR1_(from); \
 		for (k = 0; k < n; ++k) \
 			if (_NZ_(py[k])) \
@@ -80,18 +81,21 @@ SEXP CR2spV(SEXP from)
 		ERROR_INVALID_CLASS(from, __func__);
 	const char *cl = valid[ivalid];
 
+	SEXP dim = PROTECT(GET_SLOT(from, Matrix_DimSym));
+	int *pdim = INTEGER(dim), m = pdim[0], n = pdim[1];
+	Matrix_int_fast64_t mn = (Matrix_int_fast64_t) m * n;
+	UNPROTECT(1); /* dim */
+
+	if (mn > 0x1.0p+53)
+		error(_("%s length cannot exceed %s"), "sparseVector", "2^53");
+
 	/* defined in ./coerce.c : */
 	SEXP sparse_as_general(SEXP, const char *);
 	PROTECT(from = sparse_as_general(from, cl));
 
 	char vcl[] = ".sparseVector";
 	vcl[0] = cl[0];
-	SEXP to = PROTECT(NEW_OBJECT_OF_CLASS(vcl));
-
-	SEXP dim = PROTECT(GET_SLOT(from, Matrix_DimSym));
-	int *pdim = INTEGER(dim), m = pdim[0], n = pdim[1];
-	Matrix_int_fast64_t mn = (Matrix_int_fast64_t) m * n;
-	UNPROTECT(1); /* dim */
+	SEXP to = PROTECT(newObject(vcl));
 
 	SEXP p = PROTECT(GET_SLOT(from, Matrix_pSym));
 	int *pp = INTEGER(p), nnz = (cl[2] == 'C') ? pp[n] : pp[m];
